=======
Credits
=======

Development Team
----------------

CumulusCI is developed by the Salesforce.org Release Engineering team:

* Jason Lantz
* David Glick
* James Estevez
* Paul Prescod
* Bryan Oakley
* David Reed
* Brandon Parker
* Josh Kofsky
* Marcel Pufal
* David Ray

Developers Emeritus
-------------------

* Chris Polcyn
* Christian Carter

Contributors
------------

Thanks to the many community and Salesforce.org staff
contributors!

For example:

(add your name here, when you contribute through a Pull Request!)

* Ed Rivas (jerivas)
* Gustavo Tandeciarz (dcinzona)
* Chandler Anderson (zenibako)
* Ben French (BenjaminFrench)
